Displays a concise summary table of significance results for each block and joint component.
Usage
# S3 method for class 'jackstraw_rajive'
print(x, ...)Displays a concise summary table of significance results for each block and joint component.
# S3 method for class 'jackstraw_rajive'
print(x, ...)